@@ -164,7 +164,7 @@ class ValoresBase(FormularioBase):
         valor = getattr(self.model, self.fields[field].nome)
         if not valor and self.fields[field].valor_padrao:
             valor = self.fields[field].valor_padrao
-        if valor:
+        if not valor is None:
             if self.fields[field].tipo == TipoDeCampo.decimal:
                 valor = '{0:.2f}'.format(valor)
             if self.fields[field].formato == FormatoDeCampo.json and valor:
